# Pyfmrheo

In development, not fully stable.
If you find any issues please open an issue at:
https://github.com/jlopezalo/PyFMRheo/issues

If you have any questions, contact:
jla.lopez.18@gmail.com

## Installation
```
pip install pyfmrheo
```

## Usage
In the examples folder you can find several Jupyter notebooks showing how
to use the routines implemented in the library.
If you would like any other examples to be added do not hesitate to open an issue.
